/*
* Copyright (C) 2011 Sunil Mohan Adapa <sunil@medhas.org>.
* Copyright (C) 2011 O S K Chaitanya <oskchaitanya@gmail.com>.
*
* Author: Sunil Mohan Adapa <sunil@medhas.org>
*         O S K Chaitanya <oskchaitanya@gmail.com>
*
* This file is part of GNOME Nonogram.
*
* GNOME Nonogram is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* GNOME Nonogram is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with GNOME Nonogram. If not, see <http://www.gnu.org/licenses/>.
*/

const Gtk = imports.gi.Gtk;
const GObject = imports.gi.GObject;

LabelTable = new GType({
    parent: Gtk.Table.type,
    name: "LabelTable",
    init: function() {
        this.data = [[1, 11, 3], [1, 1, 4, 7, 11, 25], [7], [2, 6]];

        this.normalizeData = function() {
            var maxLength = 0;
            for(var i = 0; i < this.data.length; ++i) {
                if(maxLength < this.data[i].length)
                    maxLength = this.data[i].length;
            }

            for(var i = 0; i < this.data.length; ++i) {
                var array = this.data[i]
                for(var j = 0; j < array.length; ++j) {
                    array[j] = array[j].toString();
                }
            }

            for(var i = 0; i < this.data.length; ++i) {
                var array = this.data[i]
                var elementsToAdd = maxLength - array.length;
                for(var j = 0; j < elementsToAdd; ++j) {
                   array.unshift(" ");
                }
            }
        }

        this.populateData = function() {
            for(var i = 0; i < this.data.length; ++i) {
                var array = this.data[i]

                for(var j = 0; j < array.length; ++j) {
                    var label = new Gtk.Label({
                        label: array[j],
                        xalign: this.labelTextXAlign
                    });

                    // Assuming orientation == "horizontal" by default
                    var row = j;
                    var col = i;

                    if(this.orientation == "vertical") {
                        row = i;
                        col = j;
                    }

                    this.attach(label,
                                row, row+1, col, col+1,
                                Gtk.AttachOptions.EXPAND |
                                Gtk.AttachOptions.FILL,
                                Gtk.AttachOptions.EXPAND |
                                Gtk.AttachOptions.FILL,
                                0, 0);
                }
            }
        }

        this.normalizeData();
        this.populateData();
    }
});


RowLabelTable = new GType({
    parent: LabelTable.type,
    name: "RowLabelTable",
    class_init: function(klass, prototype) {
        prototype.orientation = "horizontal";
        prototype.labelTextXAlign = 1.0;
    }
});


ColumnLabelTable = new GType({
    parent: LabelTable.type,
    name: "ColumnLabelTable",
    class_init: function(klass, prototype) {
        prototype.orientation = "vertical";
        prototype.labelTextXAlign = 0.5;
    }
});

