/*
* Copyright (C) 2011 Sunil Mohan Adapa <sunil@medhas.org>.
* Copyright (C) 2011 O S K Chaitanya <oskchaitanya@gmail.com>.
*
* Author: Sunil Mohan Adapa <sunil@medhas.org>
*         O S K Chaitanya <oskchaitanya@gmail.com>
*
* This file is part of GNOME Nonogram.
*
* GNOME Nonogram is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* GNOME Nonogram is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with GNOME Nonogram. If not, see <http://www.gnu.org/licenses/>.
*/

const Cairo = imports.cairo;
const Gtk = imports.gi.Gtk;
const Lang = imports.lang;

PixelGrid = new GType({
    parent: Gtk.DrawingArea.type,
    name: "PixelGrid",
    init: function() {
        this.data = [
            [0, 0, 1, 1, 0, 0, 0, 1, 1, 0],
            [0, 0, 0, 1, 1, 1, 1, 1, 0, 0],
            [0, 0, 0, 0, 2, 2, 2, 0, 0, 0],
            [0, 0, 0, 0, 2, 0, 0, 0, 0, 0],
            [0, 0, 0, 0, 2, 2, 0, 0, 0, 0],
            [0, 0, 0, 0, 2, 0, 0, 0, 0, 0],
            [0, 0, 0, 0, 2, 0, 0, 0, 0, 0],
            [0, 0, 1, 1, 1, 1, 1, 1, 1, 0],
        ];

        this.numRows = this.data.length;
        this.numColumns = this.data[0].length;

        this.colors = [[0.75, 0.75, 0.75], [1.0, 1.0, 1.0], [0.0, 0.0, 0.0]];

        this.draw = function(drawingArea) {
            var cairoContext = new Cairo.Context.from_drawable(drawingArea.window);

            var size = drawingArea.window.get_size();
            cairoContext.scale(size.width / this.numColumns,
                               size.height / this.numRows);

            for(var i = 0; i < this.numRows; ++i) {
                for(var j = 0; j < this.numColumns; ++j) {
                    var colorIndex = this.data[i][j];
                    var color = this.colors[colorIndex];

                    cairoContext.set_source_rgb(color[0], color[1], color[2]);
                    cairoContext.rectangle(j, i, 1, 1);
                    cairoContext.fill();
                }
            }

            cairoContext.set_source_rgb(0.0, 0.0, 0.0);

            // TODO: change the scale to use integer boundaries for line
            // drawing
            for(var i = 0; i < this.numRows + 1; ++i) {
                cairoContext.line_width = 1.0;
                if(i % 5 == 0)
                    cairoContext.line_width = 3.0;
                if(i == 0 || i == this.numRows)
                    cairoContext.line_width = 6.0;

                cairoContext.move_to(0, i);
                cairoContext.line_to(this.numColumns, i);
                cairoContext.save();
                cairoContext.scale(this.numColumns / size.width,
                                   this.numColumns / size.height);
                cairoContext.stroke();
                cairoContext.restore();
            }

            for(var i = 0; i < this.numColumns + 1; ++i) {
                cairoContext.line_width = 1.0;
                if(i % 5 == 0)
                    cairoContext.line_width = 2.0;
                if(i == 0 || i == this.numColumns)
                    cairoContext.line_width = 4.0;

                cairoContext.move_to(i, 0);
                cairoContext.line_to(i, this.numRows);
                cairoContext.save();
                cairoContext.scale(this.numRows / size.width,
                                   this.numRows / size.height);
                cairoContext.stroke();
                cairoContext.restore();
            }

            return false;
        }

        this.signal.expose_event.connect(Lang.bind(this, this.draw));
    }
});
